@@ -368,9 +368,11 @@ class Resolver(BaseModel, T.Generic[NodeType]):
         for field_name, value_lst in kwargs.items():
             cast = conversion_map[field_name]["cast"]
             variable_name = f"{field_name}s{random_str(10)}"
-            filter_strs.append(
-                f".{field_name} in array_unpack(<array<{cast}>>${variable_name})"
-            )
+            if cast.startswith("default::"):  # if an enum or other scalar
+                s = f".{field_name} in <{cast}>array_unpack(<array<str>>${variable_name})"
+            else:
+                s = f".{field_name} in array_unpack(<array<{cast}>>${variable_name})"
+            filter_strs.append(s)
             variables[variable_name] = value_lst
         filter_str = " AND ".join(filter_strs)
         return self.filter(
